love.filesystem.load("image.lua")()

function getBullets()
    bullets = {}
	bullets_mt = getBulletsMt(bullets)
	return setmetatable(bullets, bullets_mt)
end

function getBulletsMt(bullets)
    bullets_mt = {}
	bullets_mt.__index = bullets_mt
	
	function bullets_mt:update(dt)
		for i,bullet in pairs(bullets) do
			bullet:update(dt)
			if bullet.x < -20 then
				table.remove(bullets, i)
			elseif bullet.x > love.graphics.getWidth()+20 then
				table.remove(bullets, i)
			elseif bullet.y < -20 then
				table.remove(bullets, i)
			elseif bullet.y > love.graphics.getHeight()+20 then
				table.remove(bullets, i)
			end
		end
	end
	
	function bullets_mt:draw()
	    for i,bullet in pairs(bullets) do
		    bullet:draw()
		end
	end
	
	function bullets_mt:addBullet(srcX, srcY, angle, speed)
	    bullet = getBullet(srcX, srcY, angle, speed)
		table.insert(bullets, bullet)
	end
	
	function bullets_mt:bulletSpread(srcX, srcY, angle, speed, spread, numOfBullets)
		radSpread = spread*(math.pi/180)
		bulletIncrement = radSpread/numOfBullets
		startRad = angle - radSpread/2 + bulletIncrement/2
		thisAngle = startRad
		
		for i= 1, numOfBullets do
		    bullet = getBullet(srcX, srcY, thisAngle, speed)
			thisAngle = thisAngle + bulletIncrement
			table.insert(bullets, bullet)
		end
	end
	return bullets_mt
end

function getBullet(srcX, srcY, angle, speed)
    bullet = {}
	bullet.img = getBulletImg()
	bullet.x = srcX
	bullet.y = srcY
	bullet.srcX = srcX
	bullet.srcY = srcY
	bullet.angle = angle
	bullet.speed = speed
	bullet.speedX = speed*math.cos(bullet.angle)
	bullet.speedY = speed*math.sin(bullet.angle)
	bullet.accel = 0
	bullet_mt = getBulletMt(bullet)
	return setmetatable(bullet, bullet_mt)
end	

function getBulletMt(bullet)
	bullet_mt = {}
	bullet_mt.__index = bullet_mt
	
	function bullet_mt:update(dt)
		bullet.speed = bullet.speed + bullet.accel*dt
		bullet.speedX = bullet.speed*math.cos(bullet.angle)
		bullet.speedY = bullet.speed*math.sin(bullet.angle)
		bullet.x = bullet.x + (bullet.speedX*dt) +.5*bullet.accel*math.pow(dt, 2)
		bullet.y = bullet.y + (bullet.speedY*dt) +.5*bullet.accel*math.pow(dt, 2)
	end

	function bullet_mt:draw()
		love.graphics.draw(bullet.img, bullet.x-bullet.img:getWidth()/2, bullet.y-bullet.img:getHeight()/2)
	end
	
	return bullet_mt
end    